==> rhit-1.5.1.crate: rhit-1.5.1/CHANGELOG.md <==
<a name="v1.5.1"></a>
### v1.5.1 - 2021-05-01
- look up to 3 lines of a file for a log line when checking whether it's a log file - Fix #8
- faster log parsing (about 7%)
- IP filtering allow regexes or any string based filtering

<a name="v1.5.0"></a>
### v1.5.0 - 2021-03-19
- new syntax to specify fields, allow adding from default, removing from all, etc. (the old syntax still works)
- compiles on windows (but doesn't know where the log files are) - I need testers to confirm it works
- change error message "no log found" into a more appropriate one when there was an error reading (usually lack of permission)

<a name="v1.4.1"></a>
### v1.4.1 - 2021-03-07
- small details, like the order of arguments in help

<a name="v1.4.0"></a>
### v1.4.0 - 2021-03-03
- `--lines` option to output log lines to stdout
- accept date in ISO 8601 format (previously, only the "common log format" was accepted) - Fix #3

<a name="v1.3.2"></a>
### v1.3.2 - 2021-02-23
- fix wrong version number in rhit.log file
- any file whose name contains "access.log" is considered a probable log file
- when a single file is given to rhit, its name isn't checked
- no file name is checked with `--no-name-check`

<a name="v1.3.1"></a>
### v1.3.1 - 2021-02-19
- `--all` argument to remove the filter excluding "resources" from the paths tables

<a name="v1.3.0"></a>
### v1.3.0 - 2021-02-18
Many changes in the arguments you give to rhit:
- `tables` have been renamed `fields`
- `addr` (remote IP addresses) has been changed to `ip` both in fields list and as filter
- instead of a `trends` table, there's a `--changes` argument (short: `-c`)
- with `--changes`, you see more popular and less popular referers
- with `--changes`, you see more popular and less popular remote ip adresses if the ip field is shown (eg with `rhit -f date,ip -c`)
- date filters can be negative or inequalities (eg: `-d '>2021/02/10'`)

<a name="v1.2.0"></a>
### v1.2.0 - 2021-02-12
- the `--key` argument defines the key measure, either 'hits' (default) or 'bytes' (of the response) used for sorting and filtering, and highlighted in pink
- you can filter on year or month (eg `rhit -d 2021/02`)
- trends in all tables

<a name="v1.1.1"></a>
### v1.1.1 - 2021-02-10
- when you pipe the output of rhit to a file, there's no style information. You can choose explicitly to have or not the styles and colors with the `--color` argument - Fix #1

<a name="v1.1.0"></a>
### v1.1.0 - 2021-02-09
- trends

<a name="v1.0.0"></a>
### v1.0.0 - 2021-01-29
- first public release

==> rhit-1.5.3.crate: rhit-1.5.3/CHANGELOG.md <==
<a name="v1.5.3"></a>
### v1.5.3 - 2021-07-13
- nothing new visible, small internal upgrades

<a name="v1.5.2"></a>
### v1.5.2 - 2021-06-29
- fix inability to render on narrow terminals

<a name="v1.5.1"></a>
### v1.5.1 - 2021-05-01
- look up to 3 lines of a file for a log line when checking whether it's a log file - Fix #8
- faster log parsing (about 7%)
- IP filtering allow regexes or any string based filtering

<a name="v1.5.0"></a>
### v1.5.0 - 2021-03-19
- new syntax to specify fields, allow adding from default, removing from all, etc. (the old syntax still works)
- compiles on windows (but doesn't know where the log files are) - I need testers to confirm it works
- change error message "no log found" into a more appropriate one when there was an error reading (usually lack of permission)

<a name="v1.4.1"></a>
### v1.4.1 - 2021-03-07
- small details, like the order of arguments in help

<a name="v1.4.0"></a>
### v1.4.0 - 2021-03-03
- `--lines` option to output log lines to stdout
- accept date in ISO 8601 format (previously, only the "common log format" was accepted) - Fix #3

<a name="v1.3.2"></a>
### v1.3.2 - 2021-02-23
- fix wrong version number in rhit.log file
- any file whose name contains "access.log" is considered a probable log file
- when a single file is given to rhit, its name isn't checked
- no file name is checked with `--no-name-check`

<a name="v1.3.1"></a>
### v1.3.1 - 2021-02-19
- `--all` argument to remove the filter excluding "resources" from the paths tables

<a name="v1.3.0"></a>
### v1.3.0 - 2021-02-18
Many changes in the arguments you give to rhit:
- `tables` have been renamed `fields`
- `addr` (remote IP addresses) has been changed to `ip` both in fields list and as filter
- instead of a `trends` table, there's a `--changes` argument (short: `-c`)
- with `--changes`, you see more popular and less popular referers
- with `--changes`, you see more popular and less popular remote ip adresses if the ip field is shown (eg with `rhit -f date,ip -c`)
- date filters can be negative or inequalities (eg: `-d '>2021/02/10'`)

<a name="v1.2.0"></a>
### v1.2.0 - 2021-02-12
- the `--key` argument defines the key measure, either 'hits' (default) or 'bytes' (of the response) used for sorting and filtering, and highlighted in pink
- you can filter on year or month (eg `rhit -d 2021/02`)
- trends in all tables

<a name="v1.1.1"></a>
### v1.1.1 - 2021-02-10
- when you pipe the output of rhit to a file, there's no style information. You can choose explicitly to have or not the styles and colors with the `--color` argument - Fix #1

<a name="v1.1.0"></a>
### v1.1.0 - 2021-02-09
- trends

<a name="v1.0.0"></a>
### v1.0.0 - 2021-01-29
- first public release
